Module document

Module document 

Defines additional types related to Document.

Modules

chunked_document
Defines additional types related to ChunkedDocument.
document_layout
Defines additional types related to DocumentLayout.
entity
Defines additional types related to Entity.
entity_validation_output
Defines additional types related to EntityValidationOutput.
page
Defines additional types related to Page.
page_anchor
Defines additional types related to PageAnchor.
provenance
Defines additional types related to Provenance.
revision
Defines additional types related to Revision.
style
Defines additional types related to Style.
text_anchor
Defines additional types related to TextAnchor.

Structs

Annotations
Represents the annotation of a block or a chunk.
BlobAsset
Represents a blob asset. It’s used to store the content of the inline blob in this document, for example, image bytes, such that it can be referenced by other fields in the document via asset ID.
ChunkedDocument
Represents the chunks that the document is divided into.
DocumentLayout
Represents the parsed layout of a document as a collection of blocks that the document is divided into.
EntitiesRevision
Entity revision.
Entity
An entity that could be a phrase in the text or a property that belongs to the document. It is a known entity type, such as a person, an organization, or location.
EntityRelation
Relationship between Entities.
EntityValidationOutput
The output of the validation given the document and the validation rules.
Page
A page in a Document.
PageAnchor
Referencing the visual context of the entity in the Document.pages. Page anchors can be cross-page, consist of multiple bounding polygons and optionally reference specific layout element types.
Provenance
Structure to identify provenance relationships between annotations in different revisions.
Revision
Contains past or forward revisions of this document.
ShardInfo
For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is.
Style
Annotation for common text style attributes. This adheres to CSS conventions as much as possible.
TextAnchor
Text reference indexing into the Document.text.
TextChange
This message is used for text changes aka. OCR corrections.

Enums

Original source document from the user.