BlobAsset

Struct BlobAsset 

#[non_exhaustive]
pub struct BlobAsset { pub asset_id: String, pub content: Bytes, pub mime_type: String, /* private fields */ }
Represents a blob asset. It’s used to store the content of the inline blob in this document, for example, image bytes, such that it can be referenced by other fields in the document via asset ID.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
asset_id: String

Optional. The id of the blob asset.

content: Bytes

Optional. The content of the blob asset, for example, image bytes.

mime_type: String

The mime type of the blob asset. An IANA published media type (MIME type).

Implementations

Source

impl BlobAsset

pub fn new() -> Self

pub fn set_asset_id<T: Into<String>>(self, v: T) -> Self

Sets the value of asset_id.

Example
let x = BlobAsset::new().set_asset_id("example");
pub fn set_content<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of content.

Example
let x = BlobAsset::new().set_content(bytes::Bytes::from_static(b"example"));
pub fn set_mime_type<T: Into<String>>(self, v: T) -> Self

Sets the value of mime_type.

Example
let x = BlobAsset::new().set_mime_type("example");