#[non_exhaustive]pub struct PageAnchor {
pub page_refs: Vec<PageRef>,
/* private fields */
}Expand description
Referencing the visual context of the entity in the Document.pages. Page anchors can be cross-page, consist of multiple bounding polygons and optionally reference specific layout element types.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.page_refs: Vec<PageRef>One or more references to visual page elements
Implementations
Sourceimpl PageAnchor
impl PageAnchor
pub fn new() -> Self
Sourcepub fn set_page_refs<T, V>(self, v: T) -> Self
pub fn set_page_refs<T, V>(self, v: T) -> Self