#[non_exhaustive]pub struct TextSegment {
pub start_index: i64,
pub end_index: i64,
/* private fields */
}Expand description
A text segment in the Document.text. The indices may be out of bounds which indicate that the text extends into another document shard for large sharded documents. See ShardInfo.text_offset
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_index: i64TextSegment start UTF-8 char index in the Document.text.
end_index: i64TextSegment half open end UTF-8 char index in the Document.text.
Implementations
Sourceimpl TextSegment
impl TextSegment
Sourcepub fn set_start_index<T: Into<i64>>(self, v: T) -> Self
pub fn set_start_index<T: Into<i64>>(self, v: T) -> Self