This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The processor is enabled, i.e., has an enabled version which can
currently serve processing requests and all the feature dependencies have
been successfully initialized.
The processor is being created, will become either ENABLED (for
successful creation) or FAILED (for failed ones).
Once a processor is in this state, it can then be used for document
processing, but the feature dependencies of the processor might not be
fully created yet.
The processor failed during creation or initialization of feature
dependencies. The user should delete the processor and recreate one as
all the functionalities of the processor are disabled.