#[non_exhaustive]pub struct ProcessorVersion {Show 14 fields
pub name: String,
pub display_name: String,
pub document_schema: Option<DocumentSchema>,
pub state: State,
pub create_time: Option<Timestamp>,
pub latest_evaluation: Option<EvaluationReference>,
pub kms_key_name: String,
pub kms_key_version_name: String,
pub google_managed: bool,
pub deprecation_info: Option<DeprecationInfo>,
pub model_type: ModelType,
pub satisfies_pzs: bool,
pub satisfies_pzi: bool,
pub gen_ai_model_info: Option<GenAiModelInfo>,
/* private fields */
}Expand description
A processor version is an implementation of a processor. Each processor can have multiple versions, pretrained by Google internally or uptrained by the customer. A processor can only have one default version at a time. Its document-processing behavior is defined by that version.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the processor version.
Format:
projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processor_version}
display_name: StringThe display name of the processor version.
document_schema: Option<DocumentSchema>Output only. The schema of the processor version. Describes the output.
state: StateOutput only. The state of the processor version.
create_time: Option<Timestamp>Output only. The time the processor version was created.
latest_evaluation: Option<EvaluationReference>Output only. The most recently invoked evaluation for the processor version.
kms_key_name: StringOutput only. The KMS key name used for encryption.
kms_key_version_name: StringOutput only. The KMS key version with which data is encrypted.
google_managed: boolOutput only. Denotes that this ProcessorVersion is managed by Google.
deprecation_info: Option<DeprecationInfo>Output only. If set, information about the eventual deprecation of this version.
model_type: ModelTypeOutput only. The model type of this processor version.
satisfies_pzs: boolOutput only. Reserved for future use.
satisfies_pzi: boolOutput only. Reserved for future use.
gen_ai_model_info: Option<GenAiModelInfo>Output only. Information about Generative AI model-based processor versions.
Implementations
Sourceimpl ProcessorVersion
impl ProcessorVersion
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = ProcessorVersion::new().set_display_name("example");Sourcepub fn set_document_schema<T>(self, v: T) -> Selfwhere
T: Into<DocumentSchema>,
pub fn set_document_schema<T>(self, v: T) -> Selfwhere
T: Into<DocumentSchema>,
Sets the value of document_schema.
Example
use google_cloud_documentai_v1::model::DocumentSchema;
let x = ProcessorVersion::new().set_document_schema(DocumentSchema::default()/* use setters */);Sourcepub fn set_or_clear_document_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<DocumentSchema>,
pub fn set_or_clear_document_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<DocumentSchema>,
Sets or clears the value of document_schema.
Example
use google_cloud_documentai_v1::model::DocumentSchema;
let x = ProcessorVersion::new().set_or_clear_document_schema(Some(DocumentSchema::default()/* use setters */));
let x = ProcessorVersion::new().set_or_clear_document_schema(None::<DocumentSchema>);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = ProcessorVersion::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = ProcessorVersion::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ProcessorVersion::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_latest_evaluation<T>(self, v: T) -> Selfwhere
T: Into<EvaluationReference>,
pub fn set_latest_evaluation<T>(self, v: T) -> Selfwhere
T: Into<EvaluationReference>,
Sets the value of latest_evaluation.
Example
use google_cloud_documentai_v1::model::EvaluationReference;
let x = ProcessorVersion::new().set_latest_evaluation(EvaluationReference::default()/* use setters */);Sourcepub fn set_or_clear_latest_evaluation<T>(self, v: Option<T>) -> Selfwhere
T: Into<EvaluationReference>,
pub fn set_or_clear_latest_evaluation<T>(self, v: Option<T>) -> Selfwhere
T: Into<EvaluationReference>,
Sets or clears the value of latest_evaluation.
Example
use google_cloud_documentai_v1::model::EvaluationReference;
let x = ProcessorVersion::new().set_or_clear_latest_evaluation(Some(EvaluationReference::default()/* use setters */));
let x = ProcessorVersion::new().set_or_clear_latest_evaluation(None::<EvaluationReference>);Sourcepub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
Sets the value of kms_key_name.
Example
let x = ProcessorVersion::new().set_kms_key_name("example");Sourcepub fn set_kms_key_version_name<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_version_name<T: Into<String>>(self, v: T) -> Self
Sets the value of kms_key_version_name.
Example
let x = ProcessorVersion::new().set_kms_key_version_name("example");Sourcepub fn set_google_managed<T: Into<bool>>(self, v: T) -> Self
pub fn set_google_managed<T: Into<bool>>(self, v: T) -> Self
Sets the value of google_managed.
Example
let x = ProcessorVersion::new().set_google_managed(true);Sourcepub fn set_deprecation_info<T>(self, v: T) -> Selfwhere
T: Into<DeprecationInfo>,
pub fn set_deprecation_info<T>(self, v: T) -> Selfwhere
T: Into<DeprecationInfo>,
Sets the value of deprecation_info.
Example
use google_cloud_documentai_v1::model::processor_version::DeprecationInfo;
let x = ProcessorVersion::new().set_deprecation_info(DeprecationInfo::default()/* use setters */);Sourcepub fn set_or_clear_deprecation_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeprecationInfo>,
pub fn set_or_clear_deprecation_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<DeprecationInfo>,
Sets or clears the value of deprecation_info.
Example
use google_cloud_documentai_v1::model::processor_version::DeprecationInfo;
let x = ProcessorVersion::new().set_or_clear_deprecation_info(Some(DeprecationInfo::default()/* use setters */));
let x = ProcessorVersion::new().set_or_clear_deprecation_info(None::<DeprecationInfo>);Sourcepub fn set_model_type<T: Into<ModelType>>(self, v: T) -> Self
pub fn set_model_type<T: Into<ModelType>>(self, v: T) -> Self
Sets the value of model_type.
Example
use google_cloud_documentai_v1::model::processor_version::ModelType;
let x0 = ProcessorVersion::new().set_model_type(ModelType::Generative);
let x1 = ProcessorVersion::new().set_model_type(ModelType::Custom);Sourcepub fn set_satisfies_pzs<T: Into<bool>>(self, v: T) -> Self
pub fn set_satisfies_pzs<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_satisfies_pzi<T: Into<bool>>(self, v: T) -> Self
pub fn set_satisfies_pzi<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_gen_ai_model_info<T>(self, v: T) -> Selfwhere
T: Into<GenAiModelInfo>,
pub fn set_gen_ai_model_info<T>(self, v: T) -> Selfwhere
T: Into<GenAiModelInfo>,
Sets the value of gen_ai_model_info.
Example
use google_cloud_documentai_v1::model::processor_version::GenAiModelInfo;
let x = ProcessorVersion::new().set_gen_ai_model_info(GenAiModelInfo::default()/* use setters */);Sourcepub fn set_or_clear_gen_ai_model_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<GenAiModelInfo>,
pub fn set_or_clear_gen_ai_model_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<GenAiModelInfo>,
Sets or clears the value of gen_ai_model_info.
Example
use google_cloud_documentai_v1::model::processor_version::GenAiModelInfo;
let x = ProcessorVersion::new().set_or_clear_gen_ai_model_info(Some(GenAiModelInfo::default()/* use setters */));
let x = ProcessorVersion::new().set_or_clear_gen_ai_model_info(None::<GenAiModelInfo>);Trait Implementations
Sourceimpl Clone for ProcessorVersion
impl Clone for ProcessorVersion
Sourcefn clone(&self) -> ProcessorVersion
fn clone(&self) -> ProcessorVersion
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ProcessorVersion
impl Debug for ProcessorVersion
Sourceimpl Default for ProcessorVersion
impl Default for ProcessorVersion
Sourcefn default() -> ProcessorVersion
fn default() -> ProcessorVersion
Sourceimpl Message for ProcessorVersion
impl Message for ProcessorVersion
Sourceimpl PartialEq for ProcessorVersion
impl PartialEq for ProcessorVersion
impl StructuralPartialEq for ProcessorVersion