#[non_exhaustive]pub struct TrainProcessorVersionRequest {
pub parent: String,
pub processor_version: Option<ProcessorVersion>,
pub document_schema: Option<DocumentSchema>,
pub input_data: Option<InputData>,
pub base_processor_version: String,
pub processor_flags: Option<ProcessorFlags>,
/* private fields */
}Expand description
Request message for the TrainProcessorVersion method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent (project, location and processor) to create the new
version for. Format:
projects/{project}/locations/{location}/processors/{processor}.
processor_version: Option<ProcessorVersion>Required. The processor version to be created.
document_schema: Option<DocumentSchema>Optional. The schema the processor version will be trained with.
input_data: Option<InputData>Optional. The input data used to train the ProcessorVersion.
base_processor_version: StringOptional. The processor version to use as a base for training. This
processor version must be a child of parent. Format:
projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}.
processor_flags: Option<ProcessorFlags>Implementations
Sourceimpl TrainProcessorVersionRequest
impl TrainProcessorVersionRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_processor_version<T>(self, v: T) -> Selfwhere
T: Into<ProcessorVersion>,
pub fn set_processor_version<T>(self, v: T) -> Selfwhere
T: Into<ProcessorVersion>,
Sets the value of processor_version.
Example
use google_cloud_documentai_v1::model::ProcessorVersion;
let x = TrainProcessorVersionRequest::new().set_processor_version(ProcessorVersion::default()/* use setters */);Sourcepub fn set_or_clear_processor_version<T>(self, v: Option<T>) -> Selfwhere
T: Into<ProcessorVersion>,
pub fn set_or_clear_processor_version<T>(self, v: Option<T>) -> Selfwhere
T: Into<ProcessorVersion>,
Sets or clears the value of processor_version.
Example
use google_cloud_documentai_v1::model::ProcessorVersion;
let x = TrainProcessorVersionRequest::new().set_or_clear_processor_version(Some(ProcessorVersion::default()/* use setters */));
let x = TrainProcessorVersionRequest::new().set_or_clear_processor_version(None::<ProcessorVersion>);Sourcepub fn set_document_schema<T>(self, v: T) -> Selfwhere
T: Into<DocumentSchema>,
pub fn set_document_schema<T>(self, v: T) -> Selfwhere
T: Into<DocumentSchema>,
Sets the value of document_schema.
Example
use google_cloud_documentai_v1::model::DocumentSchema;
let x = TrainProcessorVersionRequest::new().set_document_schema(DocumentSchema::default()/* use setters */);Sourcepub fn set_or_clear_document_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<DocumentSchema>,
pub fn set_or_clear_document_schema<T>(self, v: Option<T>) -> Selfwhere
T: Into<DocumentSchema>,
Sets or clears the value of document_schema.
Example
use google_cloud_documentai_v1::model::DocumentSchema;
let x = TrainProcessorVersionRequest::new().set_or_clear_document_schema(Some(DocumentSchema::default()/* use setters */));
let x = TrainProcessorVersionRequest::new().set_or_clear_document_schema(None::<DocumentSchema>);Sourcepub fn set_input_data<T>(self, v: T) -> Self
pub fn set_input_data<T>(self, v: T) -> Self
Sets the value of input_data.
Example
use google_cloud_documentai_v1::model::train_processor_version_request::InputData;
let x = TrainProcessorVersionRequest::new().set_input_data(InputData::default()/* use setters */);Sourcepub fn set_or_clear_input_data<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_input_data<T>(self, v: Option<T>) -> Self
Sets or clears the value of input_data.
Example
use google_cloud_documentai_v1::model::train_processor_version_request::InputData;
let x = TrainProcessorVersionRequest::new().set_or_clear_input_data(Some(InputData::default()/* use setters */));
let x = TrainProcessorVersionRequest::new().set_or_clear_input_data(None::<InputData>);Sourcepub fn set_base_processor_version<T: Into<String>>(self, v: T) -> Self
pub fn set_base_processor_version<T: Into<String>>(self, v: T) -> Self
Sets the value of base_processor_version.
Example
let x = TrainProcessorVersionRequest::new().set_base_processor_version("example");Sourcepub fn set_processor_flags<T: Into<Option<ProcessorFlags>>>(self, v: T) -> Self
pub fn set_processor_flags<T: Into<Option<ProcessorFlags>>>(self, v: T) -> Self
Sets the value of processor_flags.
Note that all the setters affecting processor_flags are mutually
exclusive.
Example
use google_cloud_documentai_v1::model::train_processor_version_request::CustomDocumentExtractionOptions;
let x = TrainProcessorVersionRequest::new().set_processor_flags(Some(
google_cloud_documentai_v1::model::train_processor_version_request::ProcessorFlags::CustomDocumentExtractionOptions(CustomDocumentExtractionOptions::default().into())));Sourcepub fn custom_document_extraction_options(
&self,
) -> Option<&Box<CustomDocumentExtractionOptions>>
pub fn custom_document_extraction_options( &self, ) -> Option<&Box<CustomDocumentExtractionOptions>>
The value of processor_flags
if it holds a CustomDocumentExtractionOptions, None if the field is not set or
holds a different branch.
Sourcepub fn set_custom_document_extraction_options<T: Into<Box<CustomDocumentExtractionOptions>>>(
self,
v: T,
) -> Self
pub fn set_custom_document_extraction_options<T: Into<Box<CustomDocumentExtractionOptions>>>( self, v: T, ) -> Self
Sets the value of processor_flags
to hold a CustomDocumentExtractionOptions.
Note that all the setters affecting processor_flags are
mutually exclusive.
Example
use google_cloud_documentai_v1::model::train_processor_version_request::CustomDocumentExtractionOptions;
let x = TrainProcessorVersionRequest::new().set_custom_document_extraction_options(CustomDocumentExtractionOptions::default()/* use setters */);
assert!(x.custom_document_extraction_options().is_some());
assert!(x.foundation_model_tuning_options().is_none());Sourcepub fn foundation_model_tuning_options(
&self,
) -> Option<&Box<FoundationModelTuningOptions>>
pub fn foundation_model_tuning_options( &self, ) -> Option<&Box<FoundationModelTuningOptions>>
The value of processor_flags
if it holds a FoundationModelTuningOptions, None if the field is not set or
holds a different branch.
Sourcepub fn set_foundation_model_tuning_options<T: Into<Box<FoundationModelTuningOptions>>>(
self,
v: T,
) -> Self
pub fn set_foundation_model_tuning_options<T: Into<Box<FoundationModelTuningOptions>>>( self, v: T, ) -> Self
Sets the value of processor_flags
to hold a FoundationModelTuningOptions.
Note that all the setters affecting processor_flags are
mutually exclusive.
Example
use google_cloud_documentai_v1::model::train_processor_version_request::FoundationModelTuningOptions;
let x = TrainProcessorVersionRequest::new().set_foundation_model_tuning_options(FoundationModelTuningOptions::default()/* use setters */);
assert!(x.foundation_model_tuning_options().is_some());
assert!(x.custom_document_extraction_options().is_none());Trait Implementations
Sourceimpl Clone for TrainProcessorVersionRequest
impl Clone for TrainProcessorVersionRequest
Sourcefn clone(&self) -> TrainProcessorVersionRequest
fn clone(&self) -> TrainProcessorVersionRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TrainProcessorVersionRequest
impl Debug for TrainProcessorVersionRequest
Sourceimpl Default for TrainProcessorVersionRequest
impl Default for TrainProcessorVersionRequest
Sourcefn default() -> TrainProcessorVersionRequest
fn default() -> TrainProcessorVersionRequest
impl StructuralPartialEq for TrainProcessorVersionRequest