Defines additional types related to Document.
Modules
- chunked_
document - Defines additional types related to ChunkedDocument.
- document_
layout - Defines additional types related to DocumentLayout.
- entity
- Defines additional types related to Entity.
- entity_
validation_ output - Defines additional types related to EntityValidationOutput.
- page
- Defines additional types related to Page.
- page_
anchor - Defines additional types related to PageAnchor.
- provenance
- Defines additional types related to Provenance.
- revision
- Defines additional types related to Revision.
- style
- Defines additional types related to Style.
- text_
anchor - Defines additional types related to TextAnchor.
Structs
- Annotations
- Represents the annotation of a block or a chunk.
- Blob
Asset - Represents a blob asset. It’s used to store the content of the inline blob in this document, for example, image bytes, such that it can be referenced by other fields in the document via asset ID.
- Chunked
Document - Represents the chunks that the document is divided into.
- Document
Layout - Represents the parsed layout of a document as a collection of blocks that the document is divided into.
- Entities
Revision - Entity revision.
- Entity
- An entity that could be a phrase in the text or a property that belongs to the document. It is a known entity type, such as a person, an organization, or location.
- Entity
Relation - Relationship between Entities.
- Entity
Validation Output - The output of the validation given the document and the validation rules.
- Page
- A page in a Document.
- Page
Anchor - Referencing the visual context of the entity in the Document.pages. Page anchors can be cross-page, consist of multiple bounding polygons and optionally reference specific layout element types.
- Provenance
- Structure to identify provenance relationships between annotations in different revisions.
- Revision
- Contains past or forward revisions of this document.
- Shard
Info - For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is.
- Style
- Annotation for common text style attributes. This adheres to CSS conventions as much as possible.
- Text
Anchor - Text reference indexing into the Document.text.
- Text
Change - This message is used for text changes aka. OCR corrections.
Enums
- Source
- Original source document from the user.