#[non_exhaustive]pub enum StructuredValue {
MoneyValue(Box<Money>),
DateValue(Box<Date>),
DatetimeValue(Box<DateTime>),
AddressValue(Box<PostalAddress>),
BooleanValue(bool),
IntegerValue(i32),
FloatValue(f32),
SignatureValue(bool),
}Expand description
An optional structured entity value.
Must match entity type defined in schema if
known. If this field is present, the text field could also be
populated.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
MoneyValue(Box<Money>)
Money value. See also: https://github.com/googleapis/googleapis/blob/master/google/type/money.proto
DateValue(Box<Date>)
Date value. Includes year, month, day. See also: https://github.com/googleapis/googleapis/blob/master/google/type/date.proto
DatetimeValue(Box<DateTime>)
DateTime value. Includes date, time, and timezone. See also: https://github.com/googleapis/googleapis/blob/master/google/type/datetime.proto
AddressValue(Box<PostalAddress>)
Postal address. See also: https://github.com/googleapis/googleapis/blob/master/google/type/postal_address.proto
BooleanValue(bool)
Boolean value. Can be used for entities with binary values, or for checkboxes.
IntegerValue(i32)
Integer value.
FloatValue(f32)
Float value.
SignatureValue(bool)
A signature - a graphical representation of a person’s name, often used to sign a document.