#[non_exhaustive]pub struct BlobAsset {
pub asset_id: String,
pub content: Bytes,
pub mime_type: String,
/* private fields */
}Expand description
Represents a blob asset. It’s used to store the content of the inline blob in this document, for example, image bytes, such that it can be referenced by other fields in the document via asset ID.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_id: StringOptional. The id of the blob asset.
content: BytesOptional. The content of the blob asset, for example, image bytes.
mime_type: StringThe mime type of the blob asset. An IANA published media type (MIME type).
Implementations